**********
Monitoring
**********

You can monitor the experiments and their results using either the command line, the python API or
the Web API. The command line tools help monitoring the status of experiments and inspect available
experiments in a database. The library API can also be used to query the database within python
code. Finally, the Web API facilitates the integration of the experiments' results with third party
tools.

Commands for terminal
=====================

.. _cli-info:
.. include:: cli/list.rst
.. include:: cli/status.rst
.. include:: cli/info.rst

Library API
===========

.. _library-api-results:
.. include:: library/results.rst

.. _library-api-evc-results:
.. include:: library/evc_results.rst

Web API
========

.. _web-api:
.. include:: web_api.rst
